@@ -2,8 +2,8 @@
 #
 # Rmaanova.version.R
 #
-# copyright (c) 2001-2004, Hao Wu and Gary A. Churchill, The Jackson Lab.
-# Written Apr, 2004
+# copyright (c) 2001-2004, Lei Wu and Gary A. Churchill, The Jackson Lab.
+# Written July, 2006
 #
 # Licensed under the GNU General Public License version 2 (June, 1991)
 #
@@ -14,7 +14,10 @@
 ######################################################################
 
 Rmaanova.version <- function() {
-  cat("\nCurrent R/maanova version is 1.2.0\n\n")
+    cat("\nCurrent R/maanova version is ")
+    u <- strsplit(library(help = maanova)[[3]][[1]][2], " ")[[1]]
+    cat(u[length(u)])
+    cat("\n\n")
 }
 
     
